co-words <img src="figures/200px-Rti-logo.png" align="right" />
========================================================

<br>

## What is it?
**co-words**, or co-occurring words, is a Python package enabling counting of co-occuring words in a set of documents. **co-words** allows users to find which documents share words, which words co-occur together the most often, calculate co-occurrence counts over time, and several other text analysis components. 

## Dependencies
* [scikit-learn](https://scikit-learn.org/stable/) 0.18 or higher
* [nltk](https://www.nltk.org/) 3.4 or higher
* [pandas](https://pandas.pydata.org/) 0.23 or higher 

## Installation 

```
# PyPi
pip install co-words 
```